package com.chinaitop.depot.grainAnalysis.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.depot.grainAnalysis.model.StorageExceptionAndOnfore;
import com.chinaitop.depot.grainAnalysis.model.StorageGrainAnalysis;
import com.chinaitop.depot.grainAnalysis.model.StorageGrainAnalysisExample;
import com.chinaitop.depot.grainAnalysis.service.StorageGrainAnalysisService;
import com.chinaitop.utils.ParameterUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 周粮情分析controller
 * @author User
 */
@RestController
@SuppressWarnings("all")
@RequestMapping(value = "/weekStorageGrainAnalysis")
@Api(value= "StorageGrainAnalysisController", description = "周粮情分析控制类")
public class StorageGrainAnalysisController {

	@Resource
	private StorageGrainAnalysisService analysisService;

	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="周粮情分析列表", notes = "支持分页")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="pageNum", value="页数", paramType="query"),
    	@ApiImplicitParam(name="pageSize", value="每页显示条数", paramType="query"),
    	@ApiImplicitParam(name="storehouseId", value="仓房ID", paramType="query"),
    	@ApiImplicitParam(name="storehouseCode", value="仓房编码", paramType="query"),
    	@ApiImplicitParam(name="startTime", value="起始时间", paramType="query"),
    	@ApiImplicitParam(name="endTime", value="结束时间", paramType="query")
    })
	public PageInfo<StorageGrainAnalysis> getList(Integer pageNum, Integer pageSize, String storehouseId,
			String storehouseCode, String startTime, String endTime) {

		StorageGrainAnalysisExample analysisExample = new StorageGrainAnalysisExample();
		StorageGrainAnalysisExample.Criteria analysisCriteria = analysisExample.createCriteria();

		if (null != storehouseId && !"".equals(storehouseId)) {
			analysisCriteria.andStorehouseIdEqualTo(storehouseId);
		}

		if (null != storehouseCode && !"".equals(storehouseCode)) {
			analysisCriteria.andStorehouseCodeLike("%"+storehouseCode+"%");
		}

		if (ParameterUtil.isnotnull(startTime)) {
			Date starDate = ParameterUtil.string2datetime(startTime + " 00:00:00");
			analysisCriteria.andCheckDateStartGreaterThanOrEqualTo(starDate);
		}

		if (ParameterUtil.isnotnull(endTime)) {
			Date endDate = ParameterUtil.string2datetime(endTime + " 23:59:59");
			analysisCriteria.andCheckDateStartLessThanOrEqualTo(endDate);
		}

		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}

		analysisCriteria.andAnalysisTypeEqualTo(0); //只查询周粮情分析

		analysisExample.setOrderByClause(" id desc");

		List<StorageGrainAnalysis> list = analysisService.findByCondition(analysisExample);
		PageInfo<StorageGrainAnalysis> pageInfo = new PageInfo<StorageGrainAnalysis>(list);

		return pageInfo;
	}
	
	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条周粮情分析数据", notes = "查询一条周粮情分析数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="id", value="数据ID", paramType="query"),
    	@ApiImplicitParam(name="analysisType", value="粮情分析类型数据", paramType="query")
    })
	public Map<String, Object> edit(Integer id, Integer analysisType) {

		Map<String, Object> map = new HashMap<>();

		if (null != id && !"".equals(id)) {
			map = analysisService.findByIdAnalysisObj(id, analysisType, map);
		} else {
			StorageGrainAnalysis grain = new StorageGrainAnalysis();
			map.put("grain", grain);
		}

		return map;
	}

	@RequestMapping(value="/getThreeTempDate", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条三温检查数据", notes = "查询一条三温检查数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="threeTempList", value="温度数组", paramType="query")
    })
	public Map<String, Object> getThreeTempDate(String[] threeTempList) {
		Map<String, Object> map = new HashMap<>();

		if (null != threeTempList && threeTempList.length > 0) {
			List<StorageExceptionAndOnfore> exceptionAndOnforeList = new ArrayList<>();
			StorageExceptionAndOnfore exceptionAndOnfore = new StorageExceptionAndOnfore();
			for (Object obj : threeTempList) {
//				exceptionAndOnfore.setCheckDate(ParameterUtil.string2date(obj + " 00:00:00"));
				exceptionAndOnforeList.add(exceptionAndOnfore);

				if(ParameterUtil.isnull(threeTempList[1])){
					break;
				}
			}
			map.put("exceptionAndOnforeList", exceptionAndOnforeList);
		}

		return map;
	}

	/**
	 * 提交
	 * 
	 * @param grainJson 主表数据
	 * @param exceptionJson 从表数据
	 * @param type 分析类型
	 * @param orgId 组织机构ID
	 * @param userId 用户ID
	 * @return
	 */
	@RequestMapping(value="/update", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存周粮情分析数据", notes = "保存周粮情分析数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="grainJson", value="主表数据", paramType="form"),
    	@ApiImplicitParam(name="exceptionJson", value="字表数据", paramType="form"),
    	@ApiImplicitParam(name="type", value="分析类型", paramType="form"),
    	@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="form"),
    	@ApiImplicitParam(name="userId", value="用户ID", paramType="form")
    })
	public Map<String, Object> update( String grainJson, String exceptionJson, Integer type, Integer orgId, Integer userId) {
		Map<String, Object> map = new HashMap<>();
		
		map = analysisService.updateGrainAndException(grainJson, exceptionJson, map, type, orgId, userId);
		
		return map;
	}

	/**
	 * 审核提交
	 * 
	 * @param grainJson
	 * @return
	 */
	@RequestMapping(value="/auditor_submit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="审核提交", notes = "审核提交")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="grainJson", value="主表数据", paramType="form")
    })
	public Map<String, Object> auditor_submit(String grainJson) {
		Map<String, Object> map = new HashMap<>();
		
		ObjectMapper mappers = new ObjectMapper();
		try {
			StorageGrainAnalysis grain = mappers.readValue(grainJson, StorageGrainAnalysis.class);
			grain.setAuditorStatus(1); // 新数据设置为已审核状态
			analysisService.update(grain);
		} catch (Exception e) {
			e.printStackTrace();
		}
		map.put("status", "success");
		map.put("msg", "审核成功！");
		
		return map;
	}

	@RequestMapping(value = "/editTwo", produces = MediaType.APPLICATION_JSON_VALUE, method = RequestMethod.GET)
    @ApiOperation(value = "查询周粮情分析", notes = "查询一条周粮情分析数据")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "数据集合", paramType = "query")
    })
    public Map<String, Object> editTwo(String map, Integer weekParams) {

        Map<String, Object> threeTempMap = null;
		try {
			threeTempMap = analysisService.getThreeTempData(map, weekParams);
		} catch (Exception e) {
			threeTempMap = new HashMap<String, Object>();
			e.printStackTrace();
		} finally {
			return threeTempMap;
		}
    }

}
