package com.chinaitop.depot.grainAnalysis.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.chinaitop.utils.ParameterUtil;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.chinaitop.depot.grainAnalysis.model.StorageExceptionAndOnfore;
import com.chinaitop.depot.grainAnalysis.model.StorageGrainAnalysis;
import com.chinaitop.depot.grainAnalysis.model.StorageGrainAnalysisExample;
import com.chinaitop.depot.grainAnalysis.service.StorageGrainAnalysisService;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 年粮情分析controller
 * @author User
 */
@RestController
@RequestMapping(value = "/yearStorageGrainAnalysis")
@Api(value= "YearStorageGrainAnalysisController", description = "年粮情分析控制类")
public class YearStorageGrainAnalysisController {

	@Resource
	private StorageGrainAnalysisService analysisService;

	/**
	 * 年分析查询列表
	 * 
	 * @param pageNum
	 * @param pageSize
	 * @param storehouseId
	 * @param year
	 * @return
	 */
	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="年粮情分析列表", notes = "支持分页")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="pageNum", value="页数", paramType="query"),
    	@ApiImplicitParam(name="pageSize", value="每页显示条数", paramType="query"),
    	@ApiImplicitParam(name="storehouseId", value="仓房ID", paramType="query"),
    	@ApiImplicitParam(name="year", value="年份", paramType="query")
    })
	public PageInfo<StorageGrainAnalysis> getList(Integer pageNum, Integer pageSize, String storehouseId,
			Integer year) {

		StorageGrainAnalysisExample analysisExample = new StorageGrainAnalysisExample();
		StorageGrainAnalysisExample.Criteria analysisCriteria = analysisExample.createCriteria();

		if (null != storehouseId && !"".equals(storehouseId)) {
			analysisCriteria.andStorehouseIdEqualTo(storehouseId);
		}

		if (null != year && !"".equals(year)) {
			analysisCriteria.andYearEqualTo(year);
		}

		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}

		analysisCriteria.andAnalysisTypeEqualTo(2); //只查询年粮情分析

		analysisExample.setOrderByClause(" id desc");

		List<StorageGrainAnalysis> list = analysisService.findByCondition(analysisExample);
		PageInfo<StorageGrainAnalysis> pageInfo = new PageInfo<StorageGrainAnalysis>(list);

		return pageInfo;
	}

	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条年粮情分析数据", notes = "查询一条年粮情分析数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="id", value="数据ID", paramType="query"),
    	@ApiImplicitParam(name="analysisType", value="数据类型", paramType="query")
    })
	public Map<String, Object> edit(Integer id, Integer analysisType) {

		Map<String, Object> map = new HashMap<>();

		if (null != id && !"".equals(id)) {
			map = analysisService.findByIdAnalysisObj(id, analysisType, map);
		} else {
			StorageGrainAnalysis grain = new StorageGrainAnalysis();
			map.put("grain", grain);
		}

		return map;
	}

	@RequestMapping(value="/getThreeTempDate", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条三温检查数据", notes = "查询一条三温检查数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name="houseId", value="仓房ID", paramType="query"),
			@ApiImplicitParam(name="wareId", value="货位ID", paramType="query"),
			@ApiImplicitParam(name="year", value="年份", paramType="query"),
			@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
	})
	public Map<String, Object> getThreeTempDate(String houseId, String wareId, Integer year, Integer orgId) {
		Map<String, Object> map = new HashMap<>();

		if (houseId == null) {
			map.put("status", false);
			map.put("msg", "请录入仓房编号！");
			return map;
		}
		map = analysisService.getYearThreeTempDate(houseId, wareId, year, orgId, map);

		return map;
	}

	@RequestMapping(value="/getThreeTempDateTwo", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条三温检查数据", notes = "查询一条三温检查数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name="threeList", value="需要查询三温的集合", paramType="query")
	})
	public Map<String, Object> getThreeTempDateTwo(String threeList) {
		Map<String, Object> map = new HashMap<>();

		JSONObject jsonMap = JSON.parseObject(threeList, JSONObject.class);

		List<StorageExceptionAndOnfore> exceptionAndOnforeList = new ArrayList<>();
		StorageExceptionAndOnfore exceptionAndOnfore = new StorageExceptionAndOnfore();
		exceptionAndOnfore.setCheckDate(ParameterUtil.stringTodatetime(jsonMap.getString("checkDate")));
		exceptionAndOnforeList.add(exceptionAndOnfore);

		map.put("exceptionAndOnforeList", exceptionAndOnforeList);

		map.put("status", true);

		return map;

	}

	/**
	 * 提交
	 * 
	 * @param grainJson 主表数据
	 * @param exceptionJson 从表数据
	 * @param type 分析类型
	 * @param orgId 组织机构ID
	 * @param userId 用户ID
	 * @return
	 */
	@RequestMapping(value="/update", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存周粮情分析数据", notes = "保存周粮情分析数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="grainJson", value="主表数据", paramType="form"),
    	@ApiImplicitParam(name="exceptionJson", value="字表数据", paramType="form"),
    	@ApiImplicitParam(name="type", value="分析类型", paramType="form"),
		@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="form"),
		@ApiImplicitParam(name="userId", value="用户ID", paramType="form")
    })
	public Map<String, Object> update(String grainJson, String exceptionJson, Integer type, Integer orgId, Integer userId) {
		Map<String, Object> map = new HashMap<>();
		
		map = analysisService.updateGrainAndException(grainJson, exceptionJson, map, type, orgId, userId);
		
		return map;
	}

	/**
	 * 审核提交
	 * 
	 * @param grainJson
	 * @return
	 */
	@RequestMapping(value="/auditor_submit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="审核提交", notes = "审核提交")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="grainJson", value="主表数据", paramType="form")
    })
	public Map<String, Object> auditor_submit(String grainJson) {
		Map<String, Object> map = new HashMap<>();
		
		ObjectMapper mappers = new ObjectMapper();
		StorageGrainAnalysis grain = null;
		try {
			grain = mappers.readValue(grainJson, StorageGrainAnalysis.class);
			grain.setAuditorStatus(1); // 新数据设置为已审核状态
			analysisService.update(grain);
		} catch (Exception e) {
			e.printStackTrace();
		}
		map.put("status", "success");
		map.put("msg", "审核成功！");
		
		return map;
	}
}
