package com.chinaitop.depot.grainAnalysis.controller;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.chinaitop.utils.ParameterUtil;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import com.chinaitop.depot.grainAnalysis.service.StorageGrainAnalysisService;
import com.chinaitop.depot.grainAnalysis.model.StorageExceptionAndOnfore;
import com.chinaitop.depot.grainAnalysis.model.StorageGrainAnalysis;
import com.chinaitop.depot.grainAnalysis.model.StorageGrainAnalysisExample;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

/**
 * 季度粮情分析controller
 * @author User
 */
@RestController
@RequestMapping(value = "/quarterStorageGrainAnalysis")
@Api(value= "quarterStorageGrainAnalysisController", description = "季度粮情分析控制类")
public class quarterStorageGrainAnalysisController {

	@Resource
	private StorageGrainAnalysisService analysisService;

	/**
	 * 季度分析查询列表
	 * 
	 * @param pageNum
	 * @param pageSize
	 * @param storehouseId
	 * @param year
	 * @param month
	 * @return
	 */
	@RequestMapping(value="/getList", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="季度粮情分析列表", notes = "支持分页")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="pageNum", value="页数", paramType="query"),
    	@ApiImplicitParam(name="pageSize", value="每页显示条数", paramType="query"),
    	@ApiImplicitParam(name="storehouseId", value="仓房ID", paramType="query"),
    	@ApiImplicitParam(name="year", value="年份", paramType="query"),
    	@ApiImplicitParam(name="quarter", value="季度", paramType="query")
    })
	public PageInfo<StorageGrainAnalysis> getList(Integer pageNum, Integer pageSize, String storehouseId,
			Integer year, Integer quarter) {

		StorageGrainAnalysisExample analysisExample = new StorageGrainAnalysisExample();
		StorageGrainAnalysisExample.Criteria analysisCriteria = analysisExample.createCriteria();

		if (null != storehouseId && !"".equals(storehouseId)) {
			analysisCriteria.andStorehouseIdEqualTo(storehouseId);
		}

		if (null != year && !"".equals(year)) {
			analysisCriteria.andYearEqualTo(year);
		}

		if (null != quarter && !"".equals(quarter)) {
			analysisCriteria.andMonthEqualTo(quarter);
		}

		if (null != pageNum && null != pageSize) {
			PageHelper.startPage(pageNum, pageSize);
		}

		analysisCriteria.andAnalysisTypeEqualTo(4); //只查询季度粮情分析
		
		analysisExample.setOrderByClause(" id desc");

		List<StorageGrainAnalysis> list = analysisService.findByCondition(analysisExample);
		PageInfo<StorageGrainAnalysis> pageInfo = new PageInfo<StorageGrainAnalysis>(list);

		return pageInfo;
	}

	/**
	 * 查询季度粮情详细数据
	 *
	 * @param id
	 * @param analysisType
	 * @return
	 */
	@RequestMapping(value="/edit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条季度粮情分析数据", notes = "查询一条季度粮情详细的分析数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="id", value="数据ID", paramType="query"),
    	@ApiImplicitParam(name="analysisType", value="数据类型", paramType="query")
    })
	public Map<String, Object> edit(Integer id, Integer analysisType) {

		Map<String, Object> map = new HashMap<>();

		if (null != id && !"".equals(id)) {
			map = analysisService.findByIdAnalysisObj(id, analysisType, map);
		} else {
			StorageGrainAnalysis grain = new StorageGrainAnalysis();
			map.put("grain", grain);
		}

		return map;
	}

	/**
	 * 查询三温检查数据
	 *
	 * @param houseId
	 * @param wareId
	 * @return
	 */
	@RequestMapping(value="/getThreeTempDate", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条三温检查数据", notes = "查询一条三温检查数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="houseId", value="仓房ID", paramType="query"),
    	@ApiImplicitParam(name="wareId", value="货位ID", paramType="query"),
    	@ApiImplicitParam(name="year", value="年份", paramType="query"),
    	@ApiImplicitParam(name="month", value="季度", paramType="query"),
		@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
    })
	public Map<String, Object> getThreeTempDate(String houseId, String wareId, Integer year, Integer month, Integer orgId) {
		Map<String, Object> map = new HashMap<>();
		map = analysisService.getQuarterThreeTempDate(houseId, wareId, year, month, orgId, map);
		return map;
	}

	/**
	 * 查询三温检查数据
	 *
	 * @param threeList
	 * @return
	 */
	@RequestMapping(value="/getThreeTempDateTwo", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询一条三温检查数据", notes = "查询一条三温检查数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name="threeList", value="需要查询三温的集合", paramType="query")
	})
	public Map<String, Object> getThreeTempDateTwo(String[] threeList) {
		Map<String, Object> map = new HashMap<>();

		if (null != threeList && threeList.length > 0) {
			List<StorageExceptionAndOnfore> exceptionAndOnforeList = new ArrayList<>();
			StorageExceptionAndOnfore exceptionAndOnfore = new StorageExceptionAndOnfore();
			for (Object obj : threeList) {
//				exceptionAndOnfore.setCheckDate(ParameterUtil.string2date(obj + " 00:00:00"));
				exceptionAndOnforeList.add(exceptionAndOnfore);

				if(ParameterUtil.isnull(threeList[1])){
					break;
				}
			}
			map.put("exceptionAndOnforeList", exceptionAndOnforeList);
		}

		return map;
	}

	/**
	 * 提交
	 * 
	 * @param grainJson 主表数据
	 * @param exceptionJson 从表数据
	 * @param type 分析类型
	 * @param orgId 组织机构ID
	 * @param userId 用户ID
	 * @return
	 */
	@RequestMapping(value="/update", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="保存季度粮情分析数据", notes = "保存季度粮情分析数据")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="grainJson", value="主表数据", paramType="form"),
    	@ApiImplicitParam(name="exceptionJson", value="字表数据", paramType="form"),
    	@ApiImplicitParam(name="type", value="分析类型", paramType="form"),
		@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="form"),
		@ApiImplicitParam(name="userId", value="用户ID", paramType="form")
    })
	public Map<String, Object> update(String grainJson, String exceptionJson, Integer type, Integer orgId, Integer userId) {
		Map<String, Object> map = new HashMap<>();
		
		map = analysisService.updateGrainAndException(grainJson, exceptionJson, map, type, orgId, userId);
		
		return map;
	}

	/**
	 * 审核提交
	 * 
	 * @param grainJson
	 * @return
	 */
	@RequestMapping(value="/auditor_submit", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.POST)
	@ApiOperation(value="审核提交", notes = "审核提交")
    @ApiImplicitParams({
    	@ApiImplicitParam(name="grainJson", value="主表数据", paramType="form")
    })
	public Map<String, Object> auditor_submit(String grainJson) {
		Map<String, Object> map = new HashMap<>();

		try {
			ObjectMapper mappers = new ObjectMapper();
			StorageGrainAnalysis grain = mappers.readValue(grainJson, StorageGrainAnalysis.class);
			grain.setAuditorStatus(1); // 新数据设置为已审核状态
			analysisService.update(grain);
		} catch (Exception e) {
			e.printStackTrace();
		}
		map.put("status", "success");
		map.put("msg", "审核成功！");
		
		return map;
	}

	/**
	 * 以季度份为条件查询三温数据
	 *
	 * @param houseId 仓房ID
	 * @param wareId 货位ID
	 * @param year 年
	 * @param month 季度
	 * @param orgId 粮库ID
	 * @return
	 */
	@RequestMapping(value="/getMonithThreeTempDate", produces = MediaType.APPLICATION_JSON_VALUE, method=RequestMethod.GET)
	@ApiOperation(value="查询三温数据", notes = "以季度为条件查询三温数据")
	@ApiImplicitParams({
			@ApiImplicitParam(name="houseId", value="仓房ID", paramType="query"),
			@ApiImplicitParam(name="wareId", value="货位ID", paramType="query"),
			@ApiImplicitParam(name="year", value="年份", paramType="query"),
			@ApiImplicitParam(name="month", value="季度", paramType="query"),
			@ApiImplicitParam(name="orgId", value="组织机构ID", paramType="query")
	})
	public Map<String, Object> getMonithThreeTempDate(String houseId, String wareId, Integer year, Integer month,Integer orgId) {

		Map<String, Object> map = new HashMap<>();

		map = analysisService.getQuarterThreeTempDate(houseId, wareId, year, month, orgId, map);

		return map;
	}
}

